@@ -3,7 +3,7 @@
 
 from celery import shared_task
 
-from core_parser_app.tools.parser import parser
+from core_parser_app.system import api as system_api
 
 
 @shared_task
@@ -13,4 +13,4 @@ def delete_branch_task(data_structure_element_root_id):
         data_structure_element_root_id: Data Structure Element Root id.
 
     """
-    parser.delete_branch_from_db(data_structure_element_root_id)
+    system_api.delete_branch_from_db(data_structure_element_root_id)
